{% extends "admin/change_form.html" %}

{% load i18n admin_modify adminmedia %}

{% block extrahead %}
	{{ block.super }}
	{{ error_headers }}
	<style type="text/css">
	#reporter_body { 
		padding: 8px;
		background: none repeat scroll 0 0 #FFFFCC
	}
	#reporter_body #traceback li { list-style-type: inherit; }
	#reporter_body #traceback { padding: 8px; margin-top: 10px; }
	#reporter_body td, #reporter_body th { border-bottom: 0; font:small sans-serif; line-height: auto; }
	#content { margin: 0; }
	</style>
	<style type="text/css">
	#meta { border-top: 0; }
	#meta th, #meta td { border: 0; padding: 8px; }
	#meta th { text-align: left; }
	.submit-row { display: none; }
	</style>
{% endblock %}

{% block content_title %}{% endblock %}

{% block content %}
	<table id="meta">
		<colgroup>
			<col style="width:15%"/>
			<col style="width:35%"/>
			<col style="width:15%"/>
			<col style="width:35%"/>
		</colgroup>
		<tfoot>
			<tr>
				<td colspan="4">
					{% if show_traceback %}
						<a href="?raw">&rsaquo; View plain traceback information</a>
					{% else %}
						{% if has_traceback %}
							<a href="./">&rsaquo; View interactive traceback information</a>
						{% else %}
							<em>Interactive traceback is not available for this message</em>
						{% endif %}
					{% endif %}
				</td>
			</tr>
		</tfoot>
		<tbody>
			<tr>
				<th>URL:</th>
				<td>{% if instance.url %}<a href="{{ instance.full_url }}">{{ instance.full_url }}</a>{% else %}<em>Not available</em>{% endif %}</td>
				<th>Level:</th>
				<td><a href="../?level={{ instance.level }}">{{ instance.get_level_display }}</a> (<a href="../?logger={{ instance.logger }}">{{ instance.logger }}</a>, <a href="../?logger={{ instance.logger }}&amp;level={{ instance.level }}">{{ instance.logger }}:{{ instance.get_level_display }}</a>)</td>
			</tr>
			<tr>
				<th>Server:</th>
				<td><a href="../?server_name={{ instance.server_name }}">{{ instance.server_name }}</a></td>
				<th>Date:</th>
				<td>{{ instance.datetime }}</td>
			</tr>
		</tbody>
	</table>
	{% if not show_traceback %}
		{{ block.super }}
	{% else %}
		<div id="reporter_body">
			{{ error_body }}
		</div>
	{% endif %}
{% endblock %}